@@ -1,11 +1,16 @@
 pub mod client;
+
 #[cfg(feature = "upload-file")]
 pub mod file;
+#[cfg(feature = "upload-file")]
+pub mod file_stream;
 #[cfg(feature = "upload-url")]
 pub mod link;
 
 pub use client::*;
 #[cfg(feature = "upload-file")]
 pub use file::*;
+#[cfg(feature = "upload-file")]
+pub use file_stream::*;
 #[cfg(feature = "upload-url")]
 pub use link::*;
