@@ -1,13 +1,17 @@
 mod asset;
 mod media;
+mod media_info;
 mod project;
 mod status;
 mod thumbnail;
 mod r#type;
+mod update_request;
 
 pub use asset::*;
 pub use media::*;
+pub use media_info::*;
 pub use project::*;
 pub use r#type::*;
 pub use status::*;
 pub use thumbnail::*;
+pub use update_request::*;
