@@ -1,7 +1,6 @@
-mod error;
+pub mod error;
 mod media;
 mod upload;
 
-pub use error::*;
 pub use media::*;
 pub use upload::*;
